---
title: <span class="badge object-type-scalar"></span> ClockMilliseconds
---
# <span class="badge object-type-scalar"></span> ClockMilliseconds

Time: clock (ms)

## Definition

```python
# Time: clock (ms)
ClockMilliseconds: typing.Literal["clockms"] = "clockms"
```
